package com.ruoyi.project.service;

import java.util.List;
import com.ruoyi.project.domain.TrsTechnicalResults;

/**
 * 专业术语监测Service接口
 * 
 * @author ruoyi
 * @date 2025-03-24
 */
public interface ITrsTechnicalResultsService 
{
    /**
     * 查询专业术语监测
     * 
     * @param id 专业术语监测主键
     * @return 专业术语监测
     */
    public TrsTechnicalResults selectTrsTechnicalResultsById(Long id);

    /**
     * 查询专业术语监测列表
     * 
     * @param trsTechnicalResults 专业术语监测
     * @return 专业术语监测集合
     */
    public List<TrsTechnicalResults> selectTrsTechnicalResultsList(TrsTechnicalResults trsTechnicalResults);

    /**
     * 新增专业术语监测
     * 
     * @param trsTechnicalResults 专业术语监测
     * @return 结果
     */
    public int insertTrsTechnicalResults(TrsTechnicalResults trsTechnicalResults);

    /**
     * 修改专业术语监测
     * 
     * @param trsTechnicalResults 专业术语监测
     * @return 结果
     */
    public int updateTrsTechnicalResults(TrsTechnicalResults trsTechnicalResults);

    /**
     * 批量删除专业术语监测
     * 
     * @param ids 需要删除的专业术语监测主键集合
     * @return 结果
     */
    public int deleteTrsTechnicalResultsByIds(String ids);

    /**
     * 删除专业术语监测信息
     * 
     * @param id 专业术语监测主键
     * @return 结果
     */
    public int deleteTrsTechnicalResultsById(Long id);
}
